export class AbstractStorage {
    /**
     * @param {string} _room
     * @param {string} _docname
     * @param {Y.Doc} _ydoc
     * @return {Promise<void>}
     */
    persistDoc(_room: string, _docname: string, _ydoc: Y.Doc): Promise<void>;
    /**
     * @param {string} _room
     * @param {string} _docname
     * @return {Promise<{ doc: Uint8Array, references: Array<any> }|null>}
     */
    retrieveDoc(_room: string, _docname: string): Promise<{
        doc: Uint8Array;
        references: Array<any>;
    } | null>;
    /**
     * This can be implemented by the storage provider for better efficiency. The state vector must be
     * updated when persistDoc is called. Otherwise, we pull the ydoc and compute the state vector.
     *
     * @param {string} room
     * @param {string} docname
     * @return {Promise<Uint8Array|null>}
     */
    retrieveStateVector(room: string, docname: string): Promise<Uint8Array | null>;
    /**
     * @param {string} _room
     * @param {string} _docname
     * @param {Array<any>} _storeReferences
     * @return {Promise<void>}
     */
    deleteReferences(_room: string, _docname: string, _storeReferences: Array<any>): Promise<void>;
    destroy(): Promise<void>;
}
import * as Y from 'yjs';
//# sourceMappingURL=storage.d.ts.map