export function createPostgresStorage({ database }?: {
    database?: string | undefined;
} | undefined): Promise<PostgresStorage>;
export const Storage: typeof PostgresStorage;
export type AbstractStorage = import('../storage.js').AbstractStorage;
/**
 * A Storage implementation that persists documents in PostgreSQL.
 *
 * You probably want to adapt this to your own needs.
 *
 * @implements AbstractStorage
 */
declare class PostgresStorage implements AbstractStorage {
    /**
     * @param {postgres.Sql} sql
     */
    constructor(sql: postgres.Sql);
    sql: postgres.Sql<any>;
    /**
     * @param {string} room
     * @param {string} docname
     * @param {Y.Doc} ydoc
     * @returns {Promise<void>}
     */
    persistDoc(room: string, docname: string, ydoc: Y.Doc): Promise<void>;
    /**
     * @param {string} room
     * @param {string} docname
     * @return {Promise<{ doc: Uint8Array, references: Array<number> } | null>}
     */
    retrieveDoc(room: string, docname: string): Promise<{
        doc: Uint8Array;
        references: Array<number>;
    } | null>;
    /**
     * @param {string} room
     * @param {string} docname
     * @return {Promise<Uint8Array|null>}
     */
    retrieveStateVector(room: string, docname: string): Promise<Uint8Array | null>;
    /**
     * @param {string} room
     * @param {string} docname
     * @param {Array<any>} storeReferences
     * @return {Promise<void>}
     */
    deleteReferences(room: string, docname: string, storeReferences: Array<any>): Promise<void>;
    destroy(): Promise<void>;
}
import postgres from 'postgres';
import * as Y from 'yjs';
export {};
//# sourceMappingURL=postgres.d.ts.map