export function createS3Storage(bucketName: string): S3Storage;
export function encodeS3ObjectName(room: string, docid: string, r?: string): string;
export function decodeS3ObjectName(objectName: string): {
    room: string;
    docid: string;
    r: string;
};
/**
 * @implements {AbstractStorage}
 */
export class S3Storage implements AbstractStorage {
    /**
     * @param {string} bucketName
     * @param {S3StorageConf} conf
     */
    constructor(bucketName: string, { endPoint, port, useSSL, accessKey, secretKey }: S3StorageConf);
    bucketName: string;
    client: minio.Client;
    /**
     * @param {string} room
     * @param {string} docname
     * @param {Y.Doc} ydoc
     * @returns {Promise<void>}
     */
    persistDoc(room: string, docname: string, ydoc: Y.Doc): Promise<void>;
    /**
     * @param {string} room
     * @param {string} docname
     * @return {Promise<{ doc: Uint8Array, references: Array<string> } | null>}
     */
    retrieveDoc(room: string, docname: string): Promise<{
        doc: Uint8Array;
        references: Array<string>;
    } | null>;
    /**
     * @param {string} room
     * @param {string} docname
     * @return {Promise<Uint8Array|null>}
     */
    retrieveStateVector(room: string, docname: string): Promise<Uint8Array | null>;
    /**
     * @param {string} _room
     * @param {string} _docname
     * @param {Array<string>} storeReferences
     * @return {Promise<void>}
     */
    deleteReferences(_room: string, _docname: string, storeReferences: Array<string>): Promise<void>;
    destroy(): Promise<void>;
}
export type AbstractStorage = import('../storage.js').AbstractStorage;
export type S3StorageConf = {
    endPoint: string;
    port: number;
    useSSL: boolean;
    accessKey: string;
    secretKey: string;
};
import * as minio from 'minio';
import * as Y from 'yjs';
//# sourceMappingURL=s3.d.ts.map